@@ -1,13 +1,13 @@
 """JOSE utilities."""
 import abc
-from types import ModuleType
-from typing import Union, Any, Callable, Iterator, Tuple, List, cast
-from collections.abc import Hashable, Mapping
 import sys
 import warnings
+from collections.abc import Hashable, Mapping
+from types import ModuleType
+from typing import Any, Callable, Iterator, List, Tuple, TypeVar, Union, cast
 
-from OpenSSL import crypto
 from cryptography.hazmat.primitives.asymmetric import ec, rsa
+from OpenSSL import crypto
 
 
 # Deprecated. Please use built-in decorators @classmethod and abc.abstractmethod together instead.
@@ -15,7 +15,7 @@ def abstractclassmethod(func: Callable) -> classmethod:
     return classmethod(abc.abstractmethod(func))
 
 
-class ComparableX509:  # pylint: disable=too-few-public-methods
+class ComparableX509:
     """Wrapper for OpenSSL.crypto.X509** objects that supports __eq__.
 
     :ivar wrapped: Wrapped certificate or certificate request.
@@ -52,7 +52,6 @@ class ComparableX509:  # pylint: disable=too-few-public-methods
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, self.__class__):
             return NotImplemented
-        # pylint: disable=protected-access
         return self._dump() == other._dump()
 
     def __hash__(self) -> int:
@@ -62,7 +61,7 @@ class ComparableX509:  # pylint: disable=too-few-public-methods
         return '<{0}({1!r})>'.format(self.__class__.__name__, self.wrapped)
 
 
-class ComparableKey:  # pylint: disable=too-few-public-methods
+class ComparableKey:
     """Comparable wrapper for ``cryptography`` keys.
 
     See https://github.com/pyca/cryptography/issues/2122.
@@ -82,7 +81,6 @@ class ComparableKey:  # pylint: disable=too-few-public-methods
         return getattr(self._wrapped, name)
 
     def __eq__(self, other: Any) -> bool:
-        # pylint: disable=protected-access
         if (not isinstance(other, self.__class__) or
                 self._wrapped.__class__ is not other._wrapped.__class__):
             return NotImplemented
@@ -105,7 +103,7 @@ class ComparableKey:  # pylint: disable=too-few-public-methods
         return self.__class__(self._wrapped.public_key())
 
 
-class ComparableRSAKey(ComparableKey):  # pylint: disable=too-few-public-methods
+class ComparableRSAKey(ComparableKey):
     """Wrapper for ``cryptography`` RSA keys.
 
     Wraps around:
@@ -130,7 +128,7 @@ class ComparableRSAKey(ComparableKey):  # pylint: disable=too-few-public-methods
         raise NotImplementedError()
 
 
-class ComparableECKey(ComparableKey):  # pylint: disable=too-few-public-methods
+class ComparableECKey(ComparableKey):
     """Wrapper for ``cryptography`` RSA keys.
     Wraps around:
     - :class:`~cryptography.hazmat.primitives.asymmetric.ec.EllipticCurvePrivateKey`
@@ -151,8 +149,10 @@ class ComparableECKey(ComparableKey):  # pylint: disable=too-few-public-methods
         raise NotImplementedError()
 
 
+GenericImmutableMap = TypeVar('GenericImmutableMap', bound='ImmutableMap')
+
+
 class ImmutableMap(Mapping, Hashable):
-    # pylint: disable=too-few-public-methods
     """Immutable key to value mapping with attribute access."""
 
     __slots__: Tuple[str, ...] = ()
@@ -167,10 +167,10 @@ class ImmutableMap(Mapping, Hashable):
         for slot in self.__slots__:
             object.__setattr__(self, slot, kwargs.pop(slot))
 
-    def update(self, **kwargs: Any) -> 'ImmutableMap':
+    def update(self: GenericImmutableMap, **kwargs: Any) -> GenericImmutableMap:
         """Return updated map."""
-        items = {**self, **kwargs}
-        return type(self)(**items)  # pylint: disable=star-args
+        items: Mapping[str, Any] = {**self, **kwargs}
+        return type(self)(**items)
 
     def __getitem__(self, key: str) -> Any:
         try:
@@ -197,7 +197,6 @@ class ImmutableMap(Mapping, Hashable):
 
 
 class frozendict(Mapping, Hashable):
-    # pylint: disable=invalid-name,too-few-public-methods
     """Frozen dictionary."""
     __slots__ = ('_items', '_keys')
 
