@@ -20,7 +20,7 @@ class MagicTypingTest(unittest.TestCase):
             del sys.modules['josepy.magic_typing']  # pragma: no cover
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore", category=DeprecationWarning)
-            from josepy.magic_typing import Text  # pylint: disable=no-name-in-module
+            from josepy.magic_typing import Text
         self.assertEqual(Text, text_mock)
         del sys.modules['josepy.magic_typing']
         sys.modules['typing'] = temp_typing
